pub fn load_memory_file(path: &Path) -> Option<MemoryFile>Expand description
Load a memory file with its full content, stripping frontmatter.
pub fn load_memory_file(path: &Path) -> Option<MemoryFile>Load a memory file with its full content, stripping frontmatter.