pub fn write_transcript_entry(
path: &Path,
entry: &TranscriptEntry,
) -> Result<()>Expand description
Append a transcript entry to the session file. Automatically forks to a new part file if the current one exceeds 50MB.
pub fn write_transcript_entry(
path: &Path,
entry: &TranscriptEntry,
) -> Result<()>Append a transcript entry to the session file. Automatically forks to a new part file if the current one exceeds 50MB.